@@ -1,12 +1,7 @@
 from alfred.deploy.tensorrt.common import (
-    do_inference_v2,
     build_engine_onnx_v2,
-    allocate_buffers_v2_dynamic,
-    load_engine_from_local,
-    load_torchtrt_plugins,
     check_engine,
 )
-from alfred.deploy.tensorrt.process import preprocess_torch_v1
 from alfred.utils.log import logger
 import os
 
@@ -25,10 +20,16 @@ def convert_onnx_to_tensorrt(onnx_f, datatype, min_shapes=None, opt_shapes=None,
     fp16 = False
     int8 = False
     if datatype == 16:
+        logger.info('enable fp16 mode.')
         fp16 = True
     elif datatype == 8:
         print("int8 not supported.")
-    save_p = os.path.join(os.path.dirname(onnx_f), onnx_f.replace(".onnx", ".engine"))
+    if fp16:
+        save_p = os.path.join(os.path.dirname(onnx_f), onnx_f.replace(".onnx", "_fp16.engine"))
+    elif int8:
+        save_p = os.path.join(os.path.dirname(onnx_f), onnx_f.replace(".onnx", "_int8.engine"))
+    else:
+        save_p = os.path.join(os.path.dirname(onnx_f), onnx_f.replace(".onnx", ".engine"))
     engine = build_engine_onnx_v2(
         onnx_file_path=onnx_f, engine_file_path=save_p, fp16_mode=fp16, save_engine=True, opt_params=opt_params
     )
